@@ -1,9 +1,12 @@
-from django.contrib.auth.models import AnonymousUser
-from django.http import Http404
-from power_dict.errors import NoneParameterError, InvalidParameterError, InvalidSchemeError
+import logging
+
+# from django.contrib.auth.models import AnonymousUser
+# from django.http import Http404
+from power_dict.errors import NoneParameterError, InvalidParameterError, InvalidSchemeError, NotAllowedParameterError
 from power_dict.utils import DictUtils
 from rest_framework.exceptions import ParseError, NotAuthenticated
 from rest_framework.response import Response
+from drf_toolkit.errors import ApiViewError, DjangoModelError
 
 
 class DrfUtils:
@@ -22,9 +25,15 @@ class DrfUtils:
                 InvalidParameterError,
                 NoneParameterError,
                 ParseError,
-                InvalidSchemeError
+                InvalidSchemeError,
+                DjangoModelError,
+                NotAllowedParameterError
             ]:
                 status = 400
+            elif exception_type in [
+                ApiViewError
+            ]:
+                status = exception.status
             elif exception_type in [
                 NotAuthenticated
             ]:
@@ -36,6 +45,14 @@ class DrfUtils:
             else:
                 status = 500
 
+        logger = logging.getLogger('drf_toolkit')
+
+        if logger is not None:
+            if exception is not None:
+                logger.exception(exception)
+            else:
+                logger.exception(error_message)
+
         return Response({
             'detail': error_message
         }, status=status)
@@ -96,9 +113,20 @@ class DrfUtils:
         qp = DrfUtils.get_request_parameters(request)
         return DictUtils.get_required_bool_dict_property(qp, name)
 
+    @staticmethod
+    def get_required_list_request_parameter(request, name) -> list:
+        qp = DrfUtils.get_request_parameters(request)
+        return DictUtils.get_required_list_dict_property(qp, name)
+
+    @staticmethod
+    def get_list_request_parameter(request, name, default_value=None) -> list:
+        qp = DrfUtils.get_request_parameters(request)
+        return DictUtils.get_list_dict_property(qp, name, default_value)
+
     @staticmethod
     def get_current_user(request):
         user = request.user
+        from django.contrib.auth.models import AnonymousUser
         if type(user) is AnonymousUser:
             return None
 
@@ -112,3 +140,14 @@ class DrfUtils:
             return 'anonymous'
 
         return user.username
+
+    @staticmethod
+    def transform_list_parameters(context: dict, schema: list):
+        list_rows = list(filter(lambda x: DictUtils.get_required_str_dict_property(x, 'type') == 'list', schema))
+        if len(list_rows) > 0:
+            for row in list_rows:
+                context_key = DictUtils.get_required_str_dict_property(row, 'name')
+                context_value = DictUtils.get_dict_property(context, context_key)
+                if isinstance(context_value, str):
+                    context[context_key] = context_value.split(',')
+        return context
